riptable package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   riptable.Utils
   riptable.benchmarks
   riptable.hypothesis_tests
   riptable.test_tooling_integration
   riptable.tests

Submodules
----------

riptable.rt\_accum2 module
--------------------------

.. automodule:: riptable.rt_accum2
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_accumtable module
------------------------------

.. automodule:: riptable.rt_accumtable
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_algos module
-------------------------

.. automodule:: riptable.rt_algos
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_bin module
-----------------------

.. automodule:: riptable.rt_bin
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_categorical module
-------------------------------

.. automodule:: riptable.rt_categorical
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_compressedarray module
-----------------------------------

.. automodule:: riptable.rt_compressedarray
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_csv module
-----------------------

.. automodule:: riptable.rt_csv
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_dataset module
---------------------------

.. automodule:: riptable.rt_dataset
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_datetime module
----------------------------

.. automodule:: riptable.rt_datetime
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_display module
---------------------------

.. automodule:: riptable.rt_display
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_ema module
-----------------------

.. automodule:: riptable.rt_ema
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_enum module
------------------------

.. automodule:: riptable.rt_enum
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_fastarray module
-----------------------------

.. automodule:: riptable.rt_fastarray
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_fastarraynumba module
----------------------------------

.. automodule:: riptable.rt_fastarraynumba
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_groupby module
---------------------------

.. automodule:: riptable.rt_groupby
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_groupbykeys module
-------------------------------

.. automodule:: riptable.rt_groupbykeys
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_groupbynumba module
--------------------------------

.. automodule:: riptable.rt_groupbynumba
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_groupbyops module
------------------------------

.. automodule:: riptable.rt_groupbyops
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_grouping module
----------------------------

.. automodule:: riptable.rt_grouping
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_hstack module
--------------------------

.. automodule:: riptable.rt_hstack
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_imatrix module
---------------------------

.. automodule:: riptable.rt_imatrix
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_io module
----------------------

.. automodule:: riptable.rt_io
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_itemcontainer module
---------------------------------

.. automodule:: riptable.rt_itemcontainer
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_ledger module
--------------------------

.. automodule:: riptable.rt_ledger
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_merge module
-------------------------

.. automodule:: riptable.rt_merge
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_meta module
------------------------

.. automodule:: riptable.rt_meta
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_misc module
------------------------

.. automodule:: riptable.rt_misc
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_mlutils module
---------------------------

.. automodule:: riptable.rt_mlutils
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_multiset module
----------------------------

.. automodule:: riptable.rt_multiset
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_numpy module
-------------------------

.. automodule:: riptable.rt_numpy
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_pdataset module
----------------------------

.. automodule:: riptable.rt_pdataset
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_pgroupby module
----------------------------

.. automodule:: riptable.rt_pgroupby
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_sds module
-----------------------

.. automodule:: riptable.rt_sds
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_sharedmemory module
--------------------------------

.. automodule:: riptable.rt_sharedmemory
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_sort\_cache module
-------------------------------

.. automodule:: riptable.rt_sort_cache
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_stats module
-------------------------

.. automodule:: riptable.rt_stats
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_str module
-----------------------

.. automodule:: riptable.rt_str
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_struct module
--------------------------

.. automodule:: riptable.rt_struct
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_timers module
--------------------------

.. automodule:: riptable.rt_timers
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_timezone module
----------------------------

.. automodule:: riptable.rt_timezone
   :members:
   :undoc-members:
   :show-inheritance:

riptable.rt\_utils module
-------------------------

.. automodule:: riptable.rt_utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: riptable
   :members:
   :undoc-members:
   :show-inheritance:
